<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>응용프로그램 프록시</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>프록시 타입</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 주소</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>포트</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>옵션</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>환경 설정후 실행도구의 응용프로그램 상황팝업 메뉴에서 &quot;프록시 사용&quot;을 선택하십시오</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>취소</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>저장</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>잘못된 IP 주소</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>잘못된 포트</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>연결 해제</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>취소</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>저장</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>연결 해제</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>이 환경설정을 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>유선 연결 %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>핫스팟</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>무선 연결 %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE 연결 %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>새로운 VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN 타입</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>보내기</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>네트워크</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>응용프로그램 프록시</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>개인 핫스팟</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>네트워크 세부정보</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>시스템 프록시</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>유선 네트워크</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>무선 네트워크</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>비행기 모드</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>유선 네트워크 어댑터</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>네트워크 연결 추가</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>무선 네트워크 어댑터</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>숨겨진 네트워크에 연결</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE 연결 생성</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN 상태</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN 생성</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN 가져오기</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>프록시 타입</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL 환경설정</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 주소</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>포트</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>핫스팟</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>핫스팟을 만들기</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>인터페이스</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>밴드</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>게이트웨이</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>기본 DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>넷마스크</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>접두사</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>속도</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>비행기 모드</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>잘못된 DNS 주소</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>이더넷</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>바인딩 안함</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>장치 MAC 주소</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>복사된 MAC 주소</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU 사용자 정의</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>일반</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>일반</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>이름이 이미 존재합니다</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>자동 연결</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>핫스팟</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>설정 추가</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>핫스팟을 만들기</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP 주소</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>게이트웨이</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>잘못된 IP 주소</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>잘못된 넷마스크</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>잘못된 게이트웨이</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>넷마스크</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>잘못된 IP 주소</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>잘못된 게이트웨이</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>접두사</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>자동</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>수동</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>무시</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 주소</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>게이트웨이</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>해당 리소스에만 적용됨</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>메소드</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>넷마스크</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>접두사</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>잘못된 IP 주소</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>잘못된 넷마스크</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>잘못된 게이트웨이</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>네트워크</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP 충돌</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>메소드</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>자동</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>수동</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>무시</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>네트워크 세부정보</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>시스템 프록시</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>응용프로그램 프록시</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>비행기 모드</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>네트워크 세부정보</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>네트워크</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP 충돌</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>사용안함</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>수동</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>자동</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>네트워크 관리자를 통해 구성</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>개인 핫스팟</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>서비스</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP 인증 거부</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP 인증 거부</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP 인증 거부</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP 인증 거부</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 인증 거부</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD​ 데이터 압축 안함</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>무손실 데이터 압축 안함</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP 해더 압축 안함</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>프로토콜 필드 압축 안함</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>주소/컨트롤 압축 안함</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP 에코 패킷 보냄</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE 사용</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>상태유지 MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE 연결 생성</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>시스템 프록시</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>취소</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>저장</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>프록시 타입</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>수동</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>자동</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>옵션</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>포트</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP 프록시</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS 프록시</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP 프록시</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS 프록시</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>위의 호스트 및 도메인에 대한 프록시 환경설정 무시</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL 환경설정</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>보안</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>보호된 EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>이 사용자의 비밀번호 저장</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>모든 사용자에 대한 비밀번호 저장</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>항상 묻기</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>사용안함</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>익명</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>인증됨</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>모두</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>자동</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>버전 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>버전 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP 인증</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>신원</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>비밀번호 옵션</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>개인키</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 인증서</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>사용자 인증서</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>익명 ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>제공</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC 파일</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>내부 인증</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP 버전</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>개인 비밀번호</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>인식할 수 없는 비밀번호</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>개인 WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>보안</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>키</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>보안 필수 항목</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>인식할 수 없는 비밀번호</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>개인 WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 엔터프라이즈</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation>공유 키</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>개방형 시스템</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>보안</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>인증</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>키</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN 고급</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>게이트웨이 포트 사용자 정의</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>게이트웨이 포트</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>재조정 간격 사용자 정의</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>재조정 간격</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO 데이터 압축 사용</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP 연결 사용</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP 장치 사용</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>터널 MTU 사용자 정의</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP 조각 크기 사용자 정의</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP 조각 크기</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>터널 TCP MSS 제한</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>무작위 원격 호스트</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN 고급</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>시스코 (기본값)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>보안 (기본값)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>약함</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T 사용 가능한 경우 (기본값)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>항상 NAT-T 모드</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>시스코 UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>사용안함</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH 그룹 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH 그룹 2 (기본값)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH 그룹 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>서버 (기본값)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH 그룹 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>도메인</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>벤더</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>버전</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>암호화</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT 순회 모드</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH 그룹</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>비밀 전송</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>로컬 포트</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>데드 피어 감지 사용안함</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec 사용</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>그룹 이름</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>그룹 ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>사전 공유 킵</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>1 단계 알고리즘</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>2 단계 알고리즘</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>잘못된 게이트웨이</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>게이트웨이</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 인증서</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>프록시</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>시스코 보안 바탕화면 트로이 목마 허용</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD 스크립트</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>사용자 인증서</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>개인키</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>키 암호화에 FSID 사용</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>잘못된 게이트웨이</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>인증서 (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>비밀번호가 있는 인증서 (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>정적 키</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>저장됨</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>묻기</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>필수 항목이 아닙니다</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>게이트웨이</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>인증 타입</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 인증서</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>사용자 인증서</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>개인키</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>비밀번호 옵션</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>개인 비밀번호</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>키 방향 사용자 정의</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>키 안내</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>원격 IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>로컬 IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>모두 사용가능 (기본값)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (덜 안전함)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (가장 안전)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP 인증 거부</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP 인증 거부</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP 인증 거부</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP 인증 거부</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 인증 거부</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD​ 데이터 압축 안함</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>무손실 데이터 압축 안함</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP 해더 압축 안함</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>프로토콜 필드 압축 안함</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>주소/컨트롤 압축 안함</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP 에코 패킷 보냄</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE 사용</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>보안</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>상태유지 MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN 상태</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN 생성</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN 가져오기</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>가져오기 오류</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>파일 오류</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN 프록시</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>필수 항목이 아닙니다</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>프록시 타입</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>서버 IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>포트</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>실패 시 무한 재시도</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA 파일</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>인증서 경고 무시</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>TLS 호스트 이름 확장 사용</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN 보안</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>기본값</translation>
    </message>
    <message>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>암호문</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC 인증</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>잘못된 게이트웨이</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>저장됨</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>묻기</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>필수 항목이 아닙니다</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>게이트웨이</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>비밀번호 옵션</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT 도메인</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN 프록시</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>서버 IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>포트</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>잘못된 게이트웨이</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>개인키</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH 에이전트</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>스마트 카드</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>사전 공유 킵</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>게이트웨이</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA 인증서</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>인증 타입</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>사용자 인증서</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>내부 IP 주소 요청</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP 캡슐화 적용</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP 압축 사용</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>사용자 지정 암호 제안 사용</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS 인증</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>기본값</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>고객</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>서버</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>제목 일치</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>원격 인증서 유형</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>키 파일</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>키 방향 사용자 정의</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>키 안내</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>잘못된 게이트웨이</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>저장됨</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>묻기</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>필수 항목이 아닙니다</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>게이트웨이</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>비밀번호 옵션</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>그룹 이름</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>그룹 암호</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>하이브리드 인증 사용</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA 파일</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>네트워크 케이블을 먼저 연결하세요</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>유선 네트워크 어댑터</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>네트워크 연결 추가</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>설정을　선택하기　</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>무선 네트워크 어댑터</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>핫스팟 닫기</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>무선 네트워크에 연결하려면 먼저 핫스팟을 비활성화하십시오</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>숨겨진 네트워크에 연결</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>바인딩 안함</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>필수 항목</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>장치 MAC 주소</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU 사용자 정의</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>핫스팟</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>프로토콜</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>보안 유형</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>채널</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>밴드</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>인터페이스</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>넷마스크</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>게이트웨이</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>기본 DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>접두사</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>속도</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>디바이스 사용해제됨</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>연결됨, 인터넷 없음</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>연결되지 않음</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>네트워크 케이블이 연결되어 있지 않습니다.</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>연결 중</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>인증 중</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP 주소 가져오는 중</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>연결됨</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>연결 끊김</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP 충돌</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>실패</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>주소 불러오는 중</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>유선 네트워크</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>유선 네트워크 %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>무선 네트워크</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>무선 네트워크 %1</translation>
    </message>
</context>
</TS>